package _VisualDVM.Visual.Interface;
import Common.Visual.VisualizerForm;
import _VisualDVM.ProjectData.SapforData.FileObjectWithMessages;
public interface FileWindow extends VisualizerForm {
    void ShowText();
    void ShowLanguage();
    void ShowType();
    void ShowStyle();
    default void ShowProperties() {
        ShowLanguage();
        ShowType();
        ShowStyle();
    }
    void ShowMessages();
    void ShowMessages(FileObjectWithMessages graphElement);
    void ShowNoMessages();
    void ShowLoops();
    void ShowNoLoops();
    void ShowGCOV();
    void ShowNoGCOV();
    void ShowFunctions();
    void ShowNoFunctions();
    void ShowArrays();
    void ShowNoArrays();
    void ShowCaretInfo();
    void FocusMessagesPriority(String messages_precense);
    void ShowFirstError();
    //-
    void ShowCompilationOutput();
    void ShowNoCompilationOutput();
    void ShowRunOutput();
    void ShowNoRunOutput();
    void ShowGCOVLog();
    void ShowNoGCOVLog();
    void FocusGCOVLog();
    SPFEditorInterface getEditor();
    default void ShowAllAnalyses() {
        ShowLoops();
        ShowFunctions();
        ShowArrays();
        ShowGCOV();
        ShowCompilationOutput();
        ShowRunOutput();
    }
    default void ShowNoAnalyses() {
        ShowNoLoops();
        ShowNoFunctions();
        ShowNoArrays();
        ShowNoGCOV();
        ShowNoCompilationOutput();
        ShowNoRunOutput();
    }
    void FocusLoops();
    void FocusFunctions();
    void FocusArrays();
    void RefreshTabsNames();
    void FocusCompilationOut();
    void FocusCompilationErrors();
    //--
    void ShowWarningsCount();
    void ShowErrorsCount();
    void ShowNotesCount();
    void ShowRecommendationsCount();
    //--
    void CollapseGraphs();
    void ExpandGraphs();
    //--
    void CollapseMessages();
    void ExpandMessages();
}
